CarrierWave.configure do |config|
  config.storage    = :aws
  bucket_name = S3StorageService.new.sanitise_name(ENV['S3_FILE_UPLOAD_BUCKET'])
  config.aws_bucket = bucket_name # for AWS-side bucket access permissions config, see section below
  config.aws_acl    = 'private'

  # Optionally define an asset host for configurations that are fronted by a
  # content host, such as CloudFront.
  config.asset_host = ENV['S3_ENDPOINT']

  # The maximum period for authenticated_urls is only 7 days.
  config.aws_authenticated_url_expiration = 60 * 60 * 24 * 7

  # Set custom options such as cache control to leverage browser caching.
  # You can use either a static Hash or a Proc.
  config.aws_attributes = -> { {
    expires: 1.week.from_now.httpdate,
    cache_control: 'max-age=604800'
  } }

  config.aws_credentials = {
    access_key_id:     ENV['S3_ACCESS_KEY'],
    secret_access_key: ENV['S3_SECRET_KEY'],
    region:            ENV['S3_REGION'], # Required
    stub_responses:    Rails.env.test? # Optional, avoid hitting S3 actual during tests
  }
end
