require 'rails_helper'

RSpec.describe Hyrax::Actors::ComplexAttributes do
  let(:env) { double(curation_concern: double(updated_subresources: [], :updated_subresources= => []) ) }

  before do
    class SuperClass
      def apply_save_data_to_curation_concern(env)
      end
    end

    class TestClass < SuperClass
      include Hyrax::Actors::ComplexAttributes
    end

    class ExampleWork < ActiveFedora::Base
      property :complex_person, predicate: ::RDF::URI.new('http://example.org#person'), class_name: "ComplexPerson"
      accepts_nested_attributes_for :complex_person
    end
  end

  after do
    Object.send(:remove_const, :ExampleWork)
    Object.send(:remove_const, :TestClass)
    Object.send(:remove_const, :SuperClass)
  end

  let(:test) { TestClass.new }

  describe '#apply_save_data_to_curation_concern' do
    before { test.apply_save_data_to_curation_concern(env) }
    it { expect(env.curation_concern).to have_received(:updated_subresources=).with([]) }
  end

  describe '#update_complex_metadata' do
    let(:resource) { double(complex_person: ExampleWork.new(complex_person_attributes: [{ first_name: 'John' }]).complex_person) }
    before { test.update_complex_metadata(env, resource) }
    it { expect(env.curation_concern.updated_subresources).to eql([resource.complex_person]) }
  end

  describe '#complex_attributes' do
    subject { test.complex_attributes }
    it { is_expected.to match_array(%w[complex_date complex_funding_reference complex_identifier
          complex_person complex_relation]) }
  end
end
